@@ -26,8 +26,8 @@ class DocDoc(object):
         self._subdoc_rows = None
         self._rows = []
         self._text = None
-        self.get_rows(doc)
         self.get_subdocs(doc)
+        self.get_rows(doc)
         self._width = self._get_width()
 
     def __eq__(self, other):
@@ -58,10 +58,15 @@ class DocDoc(object):
             else:
                 row = self._get_row_without_subdoc(row)
             yield row
-        subdoc_row = self._get_subdoc_row()
+        subdoc_row = True
+        if self._subdoc_rows is not None:
+            for row in self._subdoc_rows:
+                yield self._get_row_with_subdoc(['',''], row)
+        self._subdoc_rows = None
         while subdoc_row is not None:
-            yield self._get_row_with_subdoc(['',''], subdoc_row)
             subdoc_row = self._get_subdoc_row()
+            if subdoc_row is not None:
+                yield self._get_row_with_subdoc(['',''], subdoc_row)
         yield self._get_footer()
 
     def _get_row_with_subdoc(self, row, subdoc_row):
